<?php

if ( !defined( 'ABSPATH' ) ) exit;

class form_to_pdf_891_settings
{
    private $options;

    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings Admin', 
            __('Left menu Form to PDF settings', 'form-to-pdf'), 
            'manage_options', 
            'form-to-pdf-setting-admin', 
            array( $this, 'create_admin_page' )
        );
    }

    public function create_admin_page()
    {
        $this->options = form_to_pdf_891_get_options ( 'form_to_pdf_options' );
        ?>
        <div class="wrap">
            <h1><?php echo __('Form to PDF settings', 'form-to-pdf');?></h1>
            <?php
                $active_tab = isset( $_GET[ 'form-to-pdf-tab' ] ) ? $_GET[ 'form-to-pdf-tab' ] : 'readme';
            ?>
            <h2 class="nav-tab-wrapper">
                <a href="?page=form-to-pdf-setting-admin&form-to-pdf-tab=readme" class="nav-tab  <?php echo $active_tab == 'readme' ? 'nav-tab-active' : ''; ?>"><?php echo __('Using plugin', 'form-to-pdf');?></a>
                <a href="?page=form-to-pdf-setting-admin&form-to-pdf-tab=settings" class="nav-tab  <?php echo $active_tab == 'settings' ? 'nav-tab-active' : ''; ?>"><?php echo __('Plugin settings', 'form-to-pdf');?></a>
                <a href="?page=form-to-pdf-setting-admin&form-to-pdf-tab=filled" class="nav-tab  <?php echo $active_tab == 'filled' ? 'nav-tab-active' : ''; ?>"><?php echo __('Filled forms', 'form-to-pdf');?></a>
                <a href="?page=form-to-pdf-setting-admin&form-to-pdf-tab=types" class="nav-tab  <?php echo $active_tab == 'types' ? 'nav-tab-active' : ''; ?>"><?php echo __('Input types', 'form-to-pdf');?></a>
                <a href="?page=form-to-pdf-setting-admin&form-to-pdf-tab=parameters" class="nav-tab  <?php echo $active_tab == 'parameters' ? 'nav-tab-active' : ''; ?>"><?php echo __('Input parameters', 'form-to-pdf');?></a>
                <a href="?page=form-to-pdf-setting-admin&form-to-pdf-tab=other" class="nav-tab  <?php echo $active_tab == 'other' ? 'nav-tab-active' : ''; ?>"><?php echo __('Other variables', 'form-to-pdf');?></a>
            </h2>

            <?php
                switch ($active_tab){ 

                    case 'settings':
                        ?>
                        <form method="post" action="options.php">
                        <?php
                            // This prints out all hidden setting fields
                            settings_fields( 'form_to_pdf_option_main' );
                            do_settings_sections( 'form-to-pdf-setting-admin' );
                            submit_button();
                        ?>
                        </form>
                        <?php
                        exit;

                	case 'filled':
                        include(dirname(__FILE__) . '/filled.php');
                	    break;

                	case 'types':
                        include(dirname(__FILE__) . '/docs/types.php');
                	    break;
                
                	case 'parameters':
                        include(dirname(__FILE__) . '/docs/parameters.php');
                	    break;

                	case 'other':
                        include(dirname(__FILE__) . '/docs/other.php');
                        break;

                    default: 
                        echo '<h3>' . __('Using title', 'form-to-pdf'). '</h3>';
                        include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use.php' );
                        /*
                            or 
                            include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use_'.get_bloginfo('language').'.php' );
                            // include ./how_to_use_en.php
                        */
                }
            ?>

        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {        
        register_setting(
            'form_to_pdf_option_main', // Option group
            'form_to_pdf_options', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'form_to_pdf_settings_main', // ID
            __('Form to PDF Custom Settings', 'form-to-pdf'), // Title
            array( $this, 'print_section_info' ), // Callback
            'form-to-pdf-setting-admin' // Page
        );  

        add_settings_field(
            'sources', // ID
            __('Source folder', 'form-to-pdf'), // Title
            array( $this, 'sources_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

        add_settings_field(
            'template', // ID
            __('Template folder', 'form-to-pdf'), // Title
            array( $this, 'template_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

        add_settings_field(
            'load_awesome', // ID
            __('Load AweSome', 'form-to-pdf'), // Title
            array( $this, 'load_awesome_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

        add_settings_field(
            'access', // ID
            __('Access', 'form-to-pdf'), // Title
            array( $this, 'access_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );


        add_settings_field(
            'save_data', // ID
            __('Save data', 'form-to-pdf'), // Title
            array( $this, 'save_data_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

        add_settings_field(
            'save_pdf', // ID
            __('Save pdf', 'form-to-pdf'), // Title
            array( $this, 'save_pdf_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

        add_settings_field(
            'show_pdf', // ID
            __('Show pdf', 'form-to-pdf'), // Title
            array( $this, 'show_pdf_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

        add_settings_field(
            'send_admin', // ID
            __('Admin email', 'form-to-pdf'), // Title
            array( $this, 'send_admin_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

        add_settings_field(
            'google_site_key', // ID
            __('Site key for Google reCAPTHA', 'form-to-pdf'), // Title
            array( $this, 'google_site_key_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

        add_settings_field(
            'google_secret_key', // ID
            __('Secret key for Google reCAPTHA', 'form-to-pdf'), // Title
            array( $this, 'google_secret_key_callback' ), // Callback
            'form-to-pdf-setting-admin', // Page
            'form_to_pdf_settings_main' // Section
        );

    }

    public function sanitize( $input )
    {
        $new_input = array();

        if ( isset( $input['sources'] ) ) {
            $new_input['sources'] = trim( $input['sources'] );
        }
        if ( isset( $input['template'] ) ) {
            $new_input['template'] = trim( $input['template'] );
        }
        if ( isset( $input['load_awesome'] ) ) {
            $new_input['load_awesome'] = 1;
        } else {
            $new_input['load_awesome'] = 0;
        }
        if ( isset( $input['access'] ) ) {
            $new_input['access'] = trim( $input['access'] );
        }
        if ( isset( $input['save_data'] ) ) {
            $new_input['save_data'] = 1;
        } else {
            $new_input['save_data'] = 0;
        }
        if ( isset( $input['save_pdf'] ) ) {
            $new_input['save_pdf'] = 1;
        } else {
            $new_input['save_pdf'] = 0;
        }
        if ( isset( $input['show_pdf'] ) ) {
            $new_input['show_pdf'] = 1;
        } else {
            $new_input['show_pdf'] = 0;
        }
        if ( isset( $input['send_admin'] ) ) {
            $new_input['send_admin'] = 1;
        } else {
            $new_input['send_admin'] = 0;
        }
        
        if ( isset( $input['google_site_key'] ) ) {
            $new_input['google_site_key'] = trim( $input['google_site_key'] );
        }
        if ( isset( $input['google_secret_key'] ) ) {
            $new_input['google_secret_key'] = trim( $input['google_secret_key'] );
        }
        if (!empty($new_input['google_site_key']) and !empty($new_input['google_secret_key'])) {
            $new_input['filter_type'] = 'google';
        } else {
            $new_input['filter_type'] = 'fruits';
        }
        
        return $new_input;
    }

    public function print_section_info()
    {
        print __('Settings description', 'form-to-pdf');
    }

    public function sources_callback()
    {
        printf(
            '<input type="text" name="form_to_pdf_options[sources]" value="%s" />' .
            '<br /><small>'.__('Source folder description.', 'form-to-pdf').'</small>',
            isset( $this->options['sources'] ) ? esc_attr( $this->options['sources']) : ''
        );
    }

    public function template_callback()
    {
        $path = explode(DIRECTORY_SEPARATOR, dirname(__file__));
        unset($path[count($path)-1]);
        $path = implode(DIRECTORY_SEPARATOR, $path);
        if (!class_exists('form_to_pdf_891_JFiles')) {
            include_once( $path .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'files.php');
        }
        $files = new form_to_pdf_891_JFiles($path .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'templates'); 
        $templates = $files->getFolders();

        if (is_dir(get_stylesheet_directory() .DIRECTORY_SEPARATOR. 'form-to-pdf' .DIRECTORY_SEPARATOR. 'templates')) {
            $files = new form_to_pdf_891_JFiles(get_stylesheet_directory() .DIRECTORY_SEPARATOR. 'form-to-pdf' .DIRECTORY_SEPARATOR. 'templates');
            $in_themes = $files->getFolders();
            foreach ($in_themes as $theme) {
                $templates[] = array('filename' => 'theme'.DIRECTORY_SEPARATOR.$theme['filename']);
            }        
        }
        $selected = isset( $this->options['template'] ) ? esc_attr( $this->options['template']) : '';

        echo '<select name="form_to_pdf_options[template]">';
        foreach ($templates as $template) {
            echo '<option value="'.$template['filename'].'" '.selected( $selected, $template['filename'] ).'>'.$template['filename'].'</option>';
        }        
        echo '</select><br />' . 
             '<small>'.__('Template folder description.', 'form-to-pdf').'</small>';
    }

    public function load_awesome_callback()
    {
        if ($this->options['load_awesome'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<div>' .
            '   <input type="checkbox" id="form_to_pdf_options[load_awesome]" name="form_to_pdf_options[load_awesome]" value="1" '.$checked.' />' .
            '   <label for="form_to_pdf_options[load_awesome]">'.__('Load AweSome fonts', 'form-to-pdf').'</label>'.
            '</div>' .
            '<small>'.__('Load AweSome description.', 'form-to-pdf').'</small>',
            isset( $this->options['load_awesome'] ) ? esc_attr( $this->options['load_awesome']) : ''
        );
    }

    public function access_callback()
    {
        $selected = isset( $this->options['access'] ) ? esc_attr( $this->options['access']) : '';

        echo '<select name="form_to_pdf_options[access]">';
        $accesses = array(
                        'everyone' => __('everyone', 'form-to-pdf'), 
                        'guest' => __('guest', 'form-to-pdf'), 
                        'registered' => __('registered', 'form-to-pdf'), 
                        'administrator' => __('administrator', 'form-to-pdf'));
        foreach ($accesses as $key => $access) {
            echo '<option value="'.$key.'" '.selected( $selected, $key ).'>'.$access.'</option>';
        }        
        echo '</select><br />' . 
             '<small>'.__('Form access description.', 'form-to-pdf').'</small>';
    }


    public function save_data_callback()
    {
        if ($this->options['save_data'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<div>' .
            '   <input type="checkbox" id="form_to_pdf_options[save_data]" name="form_to_pdf_options[save_data]" value="1" '.$checked.' />' .
            '   <label for="form_to_pdf_options[save_data]">'.__('Save data to database', 'form-to-pdf').'</label>'.
            '</div>' .
            '<small>'.__('If you check this, you will be able to download the data in Excel. Please note that due to GDPR, you will need to ask the user for consent!', 'form-to-pdf').'</small>',
            isset( $this->options['save_data'] ) ? esc_attr( $this->options['save_data']) : ''
        );
    }

    public function save_pdf_callback()
    {
        if ($this->options['save_pdf'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<div>' .
            '   <input type="checkbox" id="form_to_pdf_options[save_pdf]" name="form_to_pdf_options[save_pdf]" value="1" '.$checked.' />' .
            '   <label for="form_to_pdf_options[save_pdf]">'.__('Save pdf to server', 'form-to-pdf').'</label>'.
            '</div>' .
            '<small>'.__('Save pdf description.', 'form-to-pdf').'</small>',
            isset( $this->options['save_pdf'] ) ? esc_attr( $this->options['save_pdf']) : ''
        );
    }


    public function show_pdf_callback()
    {
        if ($this->options['show_pdf'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<div>' .
            '   <input type="checkbox" id="form_to_pdf_options[show_pdf]" name="form_to_pdf_options[show_pdf]" value="1" '.$checked.' />' .
            '   <label for="form_to_pdf_options[show_pdf]">'.__('Show pdf in browser', 'form-to-pdf').'</label>'.
            '</div>' .
            '<small>'.__('Show pdf description.', 'form-to-pdf').'</small>',
            isset( $this->options['show_pdf'] ) ? esc_attr( $this->options['show_pdf']) : ''
        );
    }

    public function send_admin_callback()
    {
        if ($this->options['send_admin'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<div>' .
            '   <input type="checkbox" id="form_to_pdf_options[send_admin]" name="form_to_pdf_options[send_admin]" value="1" '.$checked.' />' .
            '   <label for="form_to_pdf_options[send_admin]">'.__('Enable admin email', 'form-to-pdf').'</label>'.
            '</div>' .
            '<small>'.__('Enable admin email description.', 'form-to-pdf').'</small>',
            isset( $this->options['send_admin'] ) ? esc_attr( $this->options['send_admin']) : ''
        );
    }

    public function google_site_key_callback()
    {
        printf(
            '<input type="text" class="google_site_key" name="form_to_pdf_options[google_site_key]" value="%s" style="width:300px;" /> ',
            isset( $this->options['google_site_key'] ) ? esc_attr( $this->options['google_site_key']) : ''
        );
        echo '<br /><small>'.
             __('If left blank, it will use its own robot filter. ', 'form-to-pdf').'<br />' . 
             '<a href="https://www.google.com/recaptcha/admin/create" target="_blank">' . 
             __('You can register an v2 API key here.', 'form-to-pdf').'</a></small>';
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
    }

    public function google_secret_key_callback()
    {
        printf(
            '<input type="text" class="google_secret_key" name="form_to_pdf_options[google_secret_key]" value="%s" style="width:300px;" /> ',
            isset( $this->options['google_secret_key'] ) ? esc_attr( $this->options['google_secret_key']) : ''
        );
        echo '<br /><small>'.
             __('If left blank, it will use its own robot filter. ', 'form-to-pdf') . '</small>'; 
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
    }


}
