<?php
/**
 * @version 2.0 
 * @author Dovalovszki Tamás 
 * @package Files library
 * @license All Rights Reserved - Minden jog fenntartva
 * @copyright (C) 2018 Dovalovszki Tamás - All rights reserved.
 **/

    if (!defined('DS')) {
        define( 'DS', DIRECTORY_SEPARATOR );
    }


/*
    Meghívása:
    if (!class_exists ('form_to_pdf_891_JFiles', false)) {
        include_once(dirname(__FILE__) .DIRECTORY_SEPARATOR. 'files.php');
    }
    $list = new form_to_pdf_891_JFiles('<path or url>');
    $folders = $list->getFolders();
    $files   = $list->getFiles();
*/

if (!class_exists ('form_to_pdf_891_JDescription', false)) {
    include_once(dirname(__FILE__) .DIRECTORY_SEPARATOR. 'description.php');
}

class form_to_pdf_891_JFiles extends stdClass
{
    public $path            = null;
    // Folders properties
    public $folders         = null;
    public $folderSort      = 'sortByList';
    public $folderSortOrder = 'asc';
    

    // Filess properties
    public $files           = array();
    public $allowExt        = array();
    public $filesSort       = 'sortByList';
    public $filesSortOrder  = 'asc';

    public  $is_local = true;
    public  $tilt     = array('index.htm', 'index.html', 'descript.ion', '.', '..', '.htaccess', 'filesort.txt');
    private $sortMode = null;
    private $sortList;
    private $silent   = false; // If true then not write message to code
    
	public function __construct($path = null, $silent = true)
	{
        if ($path != null) {
            if (substr($path, -1) == DIRECTORY_SEPARATOR) {
                $path = substr($path, 0, -1);
            }
            $this->path = $path;
            if (substr($path, 0, 4) == 'http') {
                $this->is_local = false;
            }
        }
        if ($silent) {
            $this->silent = true;
        }
    }    

    public function addTilt($list = null)
    {
        if ($list != null) {
            if (is_array($list)) {
                foreach ($list as $item) {
                    $this->tilt[] = $item;
                }
            } else {
                $this->tilt[] = $list;
            }
        }
    }

    function getFolders()
    {
        if ($this->is_local) {
            $this->folders = $this->getLocalFolders();
        } else {
            $this->folders = $this->getRemoteFolders();
        }
        return $this->folders;
    }

    function getLocalFolders()
    {
        $desc = new form_to_pdf_891_JDescription($this->path, $this->silent);
        $folders = array();
        $handle = @opendir($this->path);
        if ($handle) {
            while (false !== ($folder = readdir($handle)))
			{
                if ((!in_array($folder, $this->tilt)) and (is_dir($this->path .DIRECTORY_SEPARATOR. $folder))) {
                    $folders[] = array('name'     => $folder, 
                                       'title'    => $desc->getTitle($folder), 
                                       'date'     => date('Y-m-d H:i:s', filemtime($this->path .DIRECTORY_SEPARATOR. $folder)),
                                       'alias'    => $this->getAlias($folder),
                                       'filename' => $folder);
                }  
            }            
        }
        if ($this->folderSort == 'sortByList') {
            if (file_exists($this->path .DS. 'filesort.txt')) {
                $this->sortList = file($this->path .DS. 'filesort.txt', FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
            } else {
                $this->sortList = '';
                $this->folderSort = 'sortByDate';
                $this->sortMode = 'desc';
            }
        } else {
            $this->sortMode = $this->folderSortOrder;
        }
        usort($folders, array('form_to_pdf_891_JFiles', $this->folderSort));
        return $folders;
    }

    function getRemoteFolders()
    {
        $folders = array();
        $sets = stream_context_create(
            array('http'=> array('timeout' => 5)
        ));
        $source = @file_get_contents($this->path, false, $sets);
        if ($source != '') {
            
            preg_match("/<table.*?>.*?<\/[\s]*table>/s", $source, $table_html); 
            if ($table_html == null) {
                if (!$this->silent) {
                    echo "\r\n" . '<!-- JFiles: Úgy tűnik, hogy a távoli, "' . $this->path . '" mappa nem mappalistát tartalmaz. -->' . "\r\n";
                    echo '<!-- Győződjön meg róla, hogy a könyvtárban nincs index.htm, index.html, vagy index.php fájl ezáltal mappa lista helyett nem tartalom töltődik be. -->' . "\r\n";
                }
                return null;    
            }
            $table = $table_html[0];

            if (strlen($table) < (strlen($source) * 0.8)) {
                if (!$this->silent) {
                    echo "\r\n" . '<!-- JFiles: Úgy tűnik, hogy a távoli, "' . $this->path . '" mappa nem mappalistát tartalmaz. -->' . "\r\n";
                    echo '<!-- Győződjön meg róla, hogy a könyvtárban nincs index.htm, index.html, vagy index.php fájl ezáltal mappa lista helyett nem tartalom töltődik be. -->' . "\r\n";
                }
                return null;
            }
    
            preg_match_all("/<tr.*?>.*?<\/[\s]*tr>/s", $table, $rows);
            if ($rows == null) {
                return null;    
            }
            $rows = $rows[0];

            $desc = new form_to_pdf_891_JDescription($this->path, $this->silent);
    
            for ($i = 0; $i <= count($rows)-1; $i++) {
            	$source = $rows[$i];
                preg_match_all("/<td.*?>.*?<\/[\s]*td>/s", $source, $cells);
                $cells = $cells[0];
                
                if (isset($cells[1])) {
                    $tmp = trim(strip_tags($cells[1]));
                    if ((substr($tmp, -1) == '/') and (!in_array(substr($tmp, 0, -1), $this->tilt))) {
                        $date = trim(strip_tags($cells[2]));
                        if (strlen($date) < 17) { $date .= ':00'; }
                        $folders[] = array('name'     => substr($tmp, 0, -1), 
                                           'title'    => $desc->getTitle(substr($tmp, 0, -1)), 
                                           'date'     => $date,
                                           'alias'    => $this->getAlias(substr($tmp, 0, -1)),
                                           'filename' => substr($tmp, 0, -1));
                    }
                }
            }

            if ($this->folderSort == 'sortByList') {
                $this->sortList = @file_get_contents($this->path .DS. 'filesort.txt', false, $sets);
                if ($this->sortList != '') {
                    $this->sortList = explode("\r\n", $this->sortList);
                } else {
                    $this->sortList = '';
                    $this->folderSort = 'sortByDate';
                    $this->sortMode = 'desc';
                }
            } else {
                $this->sortMode = $this->folderSortOrder;
            }
            usort($folders, array('form_to_pdf_891_JFiles', $this->folderSort));
        } else {
            if (!$this->silent) {
                echo "\r\n" . '<!-- JFiles: A távoli, "' . $this->path . '" mappa nem található, vagy nem olvasható. -->' . "\r\n";
                echo '<!-- Győződjön meg róla, hogy a könyvtárban nincs index.htm, index.html, vagy index.php fájl, valamint hogy a .htaccess fájlban engedélyezve van a könyvtár listázása. (Options +Indexes)  -->' . "\r\n";
            }
        }

        return $folders;
    }


    public function getFiles($files = null)
    {
        if ($files == null) {
            if ($this->is_local) {
                $this->files = $this->getLocalList($this->path);
            } else {
                $this->files = $this->getRemoteList($this->path);
            }
        } else {
            $this->files = $files;
            for ($i = 0; $i <= count($this->files)-1; $i++) {
                if ($this->is_local) {
                    $this->files[$i]['files'] = $this->getLocalList($this->path .DIRECTORY_SEPARATOR. $this->files[$i]['name']);
                } else {
                    $this->files[$i]['files'] = $this->getRemoteList($this->path .DIRECTORY_SEPARATOR. $this->files[$i]['name']);
                }
            }
        }
        return $this->files;
    }

    function getLocalList($path)
    {
        $retFiles = null;
        $files = array();
        $handle = @opendir($path);
        if ($handle) {
            while (false !== ($file = readdir($handle)))
    		{
                if ((!in_array($file, $this->tilt)) and (!is_dir($path .DIRECTORY_SEPARATOR. $file))) {
                    $files[] = $file;     
                }
            }
        }
        
        if (count($files) > 0) {
            $desc = new form_to_pdf_891_JDescription($path, $this->silent);
            $retFiles = array();
            foreach ($files as $file) {
            
                $data = pathinfo($path .DIRECTORY_SEPARATOR. $file);
                if (!isset($data['extension'])) {
                    $data['extension'] = '';
                }
                if ((in_array(strtolower($data['extension']), $this->allowExt)) or (count($this->allowExt) == 0)) {
                    $data['filesize'] = filesize($path .DIRECTORY_SEPARATOR. $file);
                    $data['created'] = date ("Y-m-d H:i:s", filemtime($path .DIRECTORY_SEPARATOR. $file));
                    
                    $retFiles[] = array('name'  => $data['filename'], 
                                        'title'    => $desc->getTitle($data['basename']), 
                                        'alias'    => $this->getAlias($data['basename']),
                                        'ext'      => strtolower($data['extension']),
                                        'size'     => $data['filesize'],
                                        'date'     => $data['created'],
                                        'filename' => $data['basename']);
                }
            }  
            if (count($retFiles) > 0) {

                if ($this->filesSort == 'sortByList') {
                    $this->path = str_replace(DS.DS, DS, $this->path);
                    if (file_exists($this->path .DS. 'filesort.txt')) {
                        $this->sortList = file($this->path .DS. 'filesort.txt', FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
                    } else {
                        $this->sortList = '';
                        $this->filesSort = 'sortByName';
                    }
                }
                $this->sortMode = $this->filesSortOrder;
                usort($retFiles, array('form_to_pdf_891_JFiles', $this->filesSort));
            }                      
        }
        return $retFiles;
    }


    function getRemoteList($path)
    {
        $files = array();
        $sets = stream_context_create(
            array('http'=> array('timeout' => 5)
        ));
        $source = @file_get_contents($path, false, $sets);
        if ($source != '') {

            preg_match("/<table.*?>.*?<\/[\s]*table>/s", $source, $table_html); 
            if ($table_html == null) {
                if (!$this->silent) {
                    echo "\r\n" . '<!-- JFiles: Úgy tűnik, hogy a távoli, "' . $path . '" mappa nem mappalistát tartalmaz. -->' . "\r\n";
                    echo '<!-- Győződjön meg róla, hogy a könyvtárban nincs index.htm, index.html, vagy index.php fájl ezáltal mappa lista helyett nem tartalom töltődik be. -->' . "\r\n";
                }
                return null;    
            }
            $table = $table_html[0];

            if (strlen($table) < (strlen($source) * 0.8)) {
                if (!$this->silent) {
                    echo "\r\n" . '<!-- JFiles: Úgy tűnik, hogy a távoli, "' . $path . '" mappa nem mappalistát tartalmaz. -->' . "\r\n";
                    echo '<!-- Győződjön meg róla, hogy a könyvtárban nincs index.htm, index.html, vagy index.php fájl ezáltal mappa lista helyett nem tartalom töltődik be. -->' . "\r\n";
                }
                return null;
            }
    
            preg_match_all("/<tr.*?>.*?<\/[\s]*tr>/s", $table, $rows);
            if ($rows == null) {
                return null;    
            }
            $rows = $rows[0];

            if ($path == $this->path) {
                $desc = new form_to_pdf_891_JDescription($path, $this->silent);
            } else {
                $desc = new form_to_pdf_891_JDescription('', $this->silent);
            }

            $retFiles = array();
                    
            for ($i = 0; $i <= count($rows)-1; $i++) {
                preg_match_all("/<td.*?>.*?<\/[\s]*td>/s", $rows[$i], $cells);
                
                if (isset($cells[0]) and (count($cells[0]) > 0)) {
                    $cells = $cells[0];
                    preg_match( '/alt="([^"]*)"/i', $cells[0], $type );
                    $type = $type[1];
                    
                    if ((!in_array($type, array('[DIR]', '[PARENTDIR]'))) and (isset($cells[1]))) {
                        $filename = trim(strip_tags($cells[1]));
                        $ext  = explode('.', $filename);
                        $name = $ext[0];
                        $ext = $ext[1];
                        
                        if (!in_array($filename, $this->tilt) and (in_array(strtolower($ext), $this->allowExt) or (count($this->allowExt) == 0))) {
                            $date = trim(strip_tags($cells[2]));
                            if (strlen($date) < 17) { $date .= ':00'; }
                            
                            $size = trim(strip_tags($cells[3]));
                            $index = substr($size, -1);
                            switch ($index){ 
                            	case 'K':
                                    $size = substr($size, 0, -1) * 1024;
                            	    break;
                            	case 'M':
                                    $size = substr($size, 0, -1) * (1024 * 1024);
                            	    break;
                            	case 'G':
                                    $size = substr($size, 0, -1) * (1024 * 1024 * 1024);
                            	    break;
                            	default :
                            }                            
                            
                            $retFiles[] = array('name'     => $name, 
                                                'title'    => $desc->getTitle($filename), 
                                                'alias'    => $this->getAlias($filename),
                                                'ext'      => $ext,
                                                'size'     => $size,
                                                'date'     => $date,
                                                'filename' => $filename);
                            
                        }
                    }
                }
             }
            if (count($retFiles) > 0) {
                if ($this->filesSort == 'sortByList') {
                    $this->sortList = @file_get_contents($this->path .DS. 'filesort.txt', false, $sets);
                    if ($this->sortList != '') {
                        $this->sortList = explode("\r\n", $this->sortList);
                    } else {
                        $this->sortList = '';
                        $this->filesSort = 'sortByName';
                    }
                }
                $this->sortMode = $this->filesSortOrder;
                usort($retFiles, array('form_to_pdf_891_JFiles', $this->filesSort));
                $files = $retFiles;
            }                      
        } else {
            if (!$this->silent) {
                echo "\r\n" . '<!-- JFiles: A távoli, "' . $path . '" mappa nem található, vagy nem olvasható. -->' . "\r\n";
                echo '<!-- Győződjön meg róla, hogy a könyvtárban nincs index.htm, index.html, vagy index.php fájl, valamint hogy a .htaccess fájlban engedélyezve van a könyvtár listázása. (Options +Indexes)  -->' . "\r\n";
            }
        }
        return $files;
    }

    
    function sortByDate($a, $b)
    {
        if ($a['date'] == $b['date']) {
            return 0;
        }
        if ($this->sortMode == 'asc') {
            return ($b['date'] > $a['date']) ? -1 : 1;
        } else {
            return ($a['date'] > $b['date']) ? -1 : 1;
        } 
    }

    function sortByName($a, $b)
    {
        if ($this->sortMode == 'asc') {
            return strcmp(strtolower($a['name']), strtolower($b['name']));
        } else {
            return strcmp(strtolower($b['name']), strtolower($a['name']));
        }
    }

    function sortByTitle($a, $b)
    {
        if ($this->sortMode == 'asc') {
            return strcmp(strtolower($a['title']), strtolower($b['title']));
        } else {
            return strcmp(strtolower($b['title']), strtolower($a['title']));
        }
    }

    function sortByExt($a, $b)
    {
        if ($this->sortMode == 'asc') {
            return strcmp(strtolower($a['ext']), strtolower($b['ext']));
        } else {
            return strcmp(strtolower($b['ext']), strtolower($a['ext']));
        }
    }

    function sortByList($a, $b)
    {
        $key_a = array_search($a['filename'], $this->sortList);
        $key_b = array_search($b['filename'], $this->sortList);
        if ($key_a > $key_b) {
            return 1;
        } else {
            return -1;
        }
    }


    function sortBySize($a, $b)
    {
        if ($a['size'] == $b['size']) {
            return 0;
        }
        if ($this->sortMode == 'asc') {
            return ($a['size'] < $b['size']) ? -1 : 1;
        } else {
            return ($b['size'] < $a['size']) ? -1 : 1;
        }
    }

    function getAlias($text)
    {
        $str = trim(mb_strtolower($text, 'UTF-8'));

        $accented = array( "á", "é", "í", "ó", "ö", "ő", "ú", "ü", "ű" );  
        $mask     = array( "a", "e", "i", "o", "o", "o", "u", "u", "u" );  
        $str = str_replace( $accented, $mask, $str );  

        $str = str_replace('-', ' ', $str);
        $str = str_replace('.', ' ', $str);
        $str = str_replace('_', ' ', $str);
        $str = preg_replace(array('/\s+/','/[^A-Za-z0-9\-]/'), array('-',''), $str);
        
        return $str;
    }

    function checkFolder($path)
    {
		if ($path != '')
        {
            $paths = explode(DIRECTORY_SEPARATOR, $path);
            $tmp = $this->path;
            for ($i = 0; $i <= count($paths)-1; $i++) {
                if ($paths[$i] != '') {
                    $tmp .= DS. $paths[$i];
                    if (!is_dir(DS . $tmp)) {
                        mkdir(DS . $tmp, 0775);
                        file_put_contents(DS . $tmp .DS. 'index.html', '<html><body bgcolor="#FFFFFF"></body></html>');
                        chmod(DS . $tmp .DS. 'index.html', 0664);
                    }
                }
            }
            return substr($tmp, 1);
        } else {
            return false;
        }
    }

    function getEmptyName($name, $path = '')
    {
        $output = $this->path;
        if ($path != '') {
            $info = pathinfo($this->path .DS. $path .DS. $name);
            $output = $this->path .DS. $path;
        } else {
            $info = pathinfo($this->path .DS. $name);
        }
        
        $j = 0;
        $tmp = $info['filename'];
        $ext = '';
        if (isset($info['extension'])) {
            $ext = '.' . $info['extension'];
        }
        $filename = $tmp . $ext;
        while (file_exists($output .DS. $filename) != false) {
            $j++;
            $filename = $tmp . '-' . $j . $ext;
        }
        return $filename;
    }


}


?>