<?php

require_once( dirname(__file__) .DIRECTORY_SEPARATOR. 'input.php');

class JInput_form_to_pdf_891_switch extends form_to_pdf_891_JInput
{
    public function __construct($sets, $input, $variables)
    {
        parent::__construct($sets, $input, $variables);
        
        $this->type = 'switch';

        if (isset($sets['label'])) {
            $this->sets['label'] = $sets['label']; 
        }

        if (isset($sets['size'])) {
            $this->sets['size'] = $sets['size']; 
        }

        if (isset($sets['text'])) {
            $this->sets['text'] = explode('|', $sets['text']); 
        } else {
            $this->sets['text'] = array('No', 'Yes');
        }

        if (isset($sets['style'])) {
            $this->sets['style'] = explode('|', $sets['style']); 
        } else {
            $this->sets['style'] = array('primary', 'secondary');
        }

    }

    function getStyles()
    {
        wp_register_style( 'form-to-pdf-switch', plugins_url( 'form-to-pdf/assets/css/bootstrap4-toggle.min.css' ) );
    	wp_enqueue_style( 'form-to-pdf-switch' );
        return true;
    }


    function getScripts()
    {
    	// See: https://github.com/digitalBush/jquery.maskedinput
        wp_register_script('form-to-pdf-switch-js', plugins_url( 'form-to-pdf/assets/js/bootstrap4-toggle.min.js' ), array('jquery'), false, true);
    	wp_enqueue_script( 'form-to-pdf-switch-js');
        return true;
    }

    public function renderHTML()
    {
        $html = parent::renderHTML();
        $html = str_replace('[SIMPLE_ID]', $this->sets['id'], $html);
        if (isset($this->sets['label'])) {
            $html = str_replace('[LABEL]', $this->sets['label'], $html);
        } else {
            $html = str_replace('[LABEL]', '', $html);
        }

        if (isset($this->sets['size'])) {
            $html = str_replace('[SIZE]', 'data-size="'.$this->sets['size'].'"', $html);
        } else {
            $html = str_replace('[SIZE]', '', $html);
        }

        
        if (isset($this->sets['text'])) {
            $text = array();
            $text[] = 'data-on="'.__($this->sets['text'][0]).'"';
            if (isset($this->sets['text'][1])) {
                $text[] = 'data-off="'.__($this->sets['text'][1]).'"';
            }
            $text = implode(' ', $text);
            $html = str_replace('[TEXTS]', $text, $html);
        } else {
            $html = str_replace('[TEXTS]', '', $html);
        }

        if (isset($this->sets['style'])) {
            $style = array();
            $style[] = 'data-onstyle="'.$this->sets['style'][0].'"';
            if (isset($this->sets['style'][1])) {
                $style[] = 'data-offstyle="'.$this->sets['style'][1].'"';
            }
            $style = implode(' ', $style);
            $html = str_replace('[STYLES]', $style, $html);
        } else {
            $html = str_replace('[STYLES]', '', $html);
        }

        
        $checked = '';
        if (isset($this->sets['checked'])) {
            $checked = 'CHECKED';
        } 
        $html = str_replace('[CHECKED]', $checked, $html);
        
        return $html;
    }
    
    public function renderHTML_old()
    {
        if (isset($_REQUEST[$this->sets['id']])) {
            $value = sanitize_text_field($_REQUEST[$this->sets['id']]);
        } else {
            if (isset($this->sets['value'])) {
                $value = $this->sets['value'];
            } else {
                $value = '';
            }
        }
        if (isset($this->sets['class'])) { $class = $this->sets['class']; } else { $class = '';}
        if (isset($this->sets['invalid'])) { $invalidText = $this->sets['invalid']; } else { $invalidText = '';}
        if (isset($this->sets['other'])) { $other = $this->sets['other']; } else { $other = '';}

        if (isset($this->sets['required'])) { 
            $required = 'required="required"';
            $check = 'onkeypress="form_item_check(\''.$this->sets['id'].'\');" '; 
        } else { 
            $required = '';
            $check = '';
        }

        if (isset($this->sets['checked'])) {
            $checked = 'CHECKED';
        } else {
            if ($value == 1) {
                $checked = 'CHECKED';
            } else {
                $checked = '';
            }
        }

        
        $html = "\r\n" . 
                '<div class="custom-control custom-checkbox">' . "\r\n" .
                '   <input type="checkbox" class="'.$class.' custom-control-input" id="'.$this->sets['id'].'" name="'.$this->sets['id'].'" value="1" '.$checked.' '.$required.' '.$check.' '.$other.'>' . "\r\n" .
                '   <label class="custom-control-label" for="'.$this->sets['id'].'">'.$this->sets['label'].'</label>' . "\r\n" .
                '</div>' . "\r\n"; 

        if ($invalidText != '') {
            $html .= '   <div class="invalid-feedback">' . "\r\n" .
                     '       ' . $invalidText . "\r\n" .
                     '   </div>' . "\r\n";
        }
        if (isset($this->sets['description'])) {
            $html .= '<small class="form-text text-muted">' .  $this->sets['description'] . '</small>' .  "\r\n";
        }

        return $html;
    }
}

?>